@@ -91,6 +91,7 @@ class AlignmentDataset(Dataset):
         show_warnings=False,
         punctuation_marks="!?.,;",
         tmp_directory=None,
+        chunk_size=100,
     ):
         super().__init__()
         __metaclass__ = abc.ABCMeta
@@ -99,6 +100,7 @@ class AlignmentDataset(Dataset):
         self.source_url = source_url
         self.show_warnings = show_warnings
         self.punctuation_marks = punctuation_marks
+        self.chunk_size = chunk_size
         if tmp_directory is None:
             self.tmp_directory = Path("/tmp/alignments")
         else:
@@ -259,7 +261,7 @@ class AlignmentDataset(Dataset):
         for item in process_map(
                 self._create_item,
                 self.files,
-                chunksize=100,
+                chunksize=self.chunk_size,
                 max_workers=multiprocessing.cpu_count(),
                 desc="collecting textgrid and audio files",
                 tqdm_class=tqdm,
